@@ -3,7 +3,7 @@
 # @Email:  kramer@mpi-cbg.de
 # @Project: go-with-the-flow
 # @Last modified by:    Felix Kramer
-# @Last modified time: 2021-06-22T23:26:41+02:00
+# @Last modified time: 2021-08-18T11:11:11+02:00
 # @License: MIT
 
 # standard types
@@ -73,6 +73,8 @@ class circuit:
         )
         self.set_graph_containers()
 
+        self.draw_weight_scaling=1.
+
     def set_graph_containers(self):
 
         self.G=nx.DiGraph()
@@ -229,21 +231,24 @@ class circuit:
 
         return pos
 
-    def set_pos(self,pos_data):
+    def set_pos(self,pos_data={}):
 
         pos_key='pos'
         reset_layout=False
+        nodata=False
+        if len(pos_data.values())==0:
+            nodata=True
+
         for j,n in enumerate(self.G.nodes()):
             if pos_key not in self.G.nodes[n]:
                 reset_layout=True
-        if reset_layout:
+        if reset_layout and nodata:
             print('set networkx.spring_layout()')
             pos = nx.spring_layout(self.G)
-            for j,n in enumerate(self.G.nodes()):
-                self.G.nodes[n]=pos[n]
+            nx.set_node_attributes(self.G, pos, 'pos')
         else:
-            for j,n in enumerate(self.G.nodes()):
-                self.G.nodes[n]=pos_data[n]
+            nx.set_node_attributes(self.G, pos_data, 'pos')
+
 
     def set_scale_pars(self, new_parameters):
 
@@ -254,9 +259,9 @@ class circuit:
         self.graph=new_parameters
 
     # output
-
     def plot_circuit(self):
 
+        self.set_pos()
         fig=dx.plot_networkx(   self.G, edge_list=self.list_graph_edges, node_list=self.list_graph_nodes )
 
         return fig
